aboutsummaryrefslogtreecommitdiff
path: root/src/or/rendcommon.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/or/rendcommon.c')
-rw-r--r--src/or/rendcommon.c8
1 files changed, 6 insertions, 2 deletions
diff --git a/src/or/rendcommon.c b/src/or/rendcommon.c
index a664b5d50..9bf5533a8 100644
--- a/src/or/rendcommon.c
+++ b/src/or/rendcommon.c
@@ -198,8 +198,8 @@ rend_encode_v2_intro_points(char **encoded, rend_service_descriptor_t *desc)
log_warn(LD_REND, "Could not write onion key.");
goto done;
}
- /* Encode intro key. */
- intro_key = intro->intro_key;
+ /* Encode the service key, rather than the intro key. */
+ intro_key = desc->pk;
if (!intro_key ||
crypto_pk_write_public_key_to_string(intro_key, &service_key,
&service_key_len) < 0) {
@@ -207,6 +207,10 @@ rend_encode_v2_intro_points(char **encoded, rend_service_descriptor_t *desc)
tor_free(onion_key);
goto done;
}
+ log_info(LD_REND, "Got service key:\n%s for introduction point %s",
+ safe_str_client(service_key),
+ safe_str_client(intro->extend_info->nickname));
+
/* Assemble everything for this introduction point. */
address = tor_dup_addr(&info->addr);
res = tor_snprintf(unenc + unenc_written, unenc_len - unenc_written,